@@ -230,6 +230,8 @@ case "Cartella":  				$messaggio = "Mapp"; break;
 case "alla cartella":  				$messaggio = "till mapp"; break;
 case "Importa":  				$messaggio = "Importera"; break;
 case "con i servizi opzionali selezionati":  	$messaggio = "med valda extratj&auml;nster"; break;
+case "chiedere":  				$messaggio = "ask"; break;
+case "il":  					$messaggio = "the"; break;
 case "Crea pagine per il sito web":  		$messaggio = "Create website pages"; break;
 case "Postgresql":  				$messaggio = "Postgresql"; break;
 case "Mysql":  					$messaggio = "Mysql"; break;
@@ -238,6 +240,7 @@ case "Pagina per controllare la disponibilità":	$messaggio = "Page to check ava
 case "Tariffe (tipologie) da mostrare ed eventuali loro nomi sostitutivi con cui mostrarle":	$messaggio = "Rates (types) to show and their eventual substitutive names to be shown with"; break;
 case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivations of assignment rules 1 for conditional availability to consider"; break;
 case "Crea la pagina per la disponibilità":  	$messaggio = "Create availability page"; break;
+case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
 case "E' necessario inserire il numero di persone per questa tipologia":	$messaggio = "The number of people is needed for this type"; break;
 case "Periodo":  				$messaggio = "Period"; break;
 case "Una pagina chiamata":  			$messaggio = "A page called"; break;
@@ -272,7 +275,7 @@ case "Data di partenza":  			$messaggio = "Departure date"; break;
 case "Tipologia":  				$messaggio = "Type"; break;
 case "default - frame orizzontale":  		$messaggio = "default - horizontal frame"; break;
 case "Condizioni da accettare nella form":  	$messaggio = "Agreements to be accepted in the form"; break;
-case "nomi dall'utente delle liste, opzionali nel commento":	$messaggio = "names from lists user, optionals in comment"; break;
+case "nomi dall'utente delle liste":		$messaggio = "names from lists user"; break;
 case "Accetto":  				$messaggio = "I accept"; break;
 case "documento":  				$messaggio = "document"; break;
 case "larghezza":  				$messaggio = "width"; break;
@@ -289,8 +292,34 @@ case "Categoria":  				$messaggio = "Category"; break;
 case "Attenzione":  				$messaggio = "Warning"; break;
 case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
 case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
-case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
 case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset for position"; break;
+case "aggiunto al commento":  			$messaggio = "added to comment"; break;
+case "aggiunto al campo":  			$messaggio = "added to field"; break;
+case "del cliente":  				$messaggio = "in client data"; break;
+case "URL file css":  				$messaggio = "URL of css file"; break;
+case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
+case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
+case "Partita iva":  				$messaggio = "VAT number"; break;
+case "mai":  					$messaggio = "never"; break;
+case "se possibile":  				$messaggio = "when possible"; break;
+case "sempre":  				$messaggio = "always"; break;
+case "posizioni vicine":  			$messaggio = "nearby positions"; break;
+case "con posizioni vicine":  			$messaggio = "with nearby positions"; break;
+case "Indirizzi alternativi da cui la pagina è raggiungibile":	$messaggio = "Alternative addresses from which the page can be reached"; break;
+case "sicuro":  				$messaggio = "secure"; break;
+case "usare uno spazio per non mostrare il costo nei dettagli":	$messaggio = "use a space to don't show the cost in the details"; break;
+case "Codici promozionali":  			$messaggio = "Promotional codes"; break;
+case "Il codice":  				$messaggio = "The code"; break;
+case "aggiunge":  				$messaggio = "adds"; break;
+case "rimuove":  				$messaggio = "removes"; break;
+case "Codice promozionale":  			$messaggio = "Promotional code"; break;
+case "Solo quelli selezionati per essere mostrati":	$messaggio = "only the ones selected to be shown"; break;
+case "Codice promozionale applicato":  		$messaggio = "Promotional code applied"; break;
+case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "some extra costs with promotional code"; break;
+case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "are not associated to any rate, some of their characteristics may be altered if not compatible"; break;
+case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
+case "titolo html":  				$messaggio = "html title"; break;
+case "titolo":  				$messaggio = "title"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -333,6 +362,8 @@ case "var_chiedi_costi_aggiuntivi_di_pag_inserzione":	$messaggio = "var_ask_for_
 case "var_costi_aggiuntivi_mostra":  		$messaggio = "var_extra_costs_to_show"; break;
 case "var_nomi_costi_agg_imposti":  		$messaggio = "var_imposed_extra_costs_names"; break;
 case "var_categorie_costi_agg_imposte":  	$messaggio = "var_imposed_extra_costs_categories"; break;
+case "var_campi_codici_promo":  		$messaggio = "var_fields_promo_codes"; break;
+case "var_costi_campi_codici_promo":  		$messaggio = "var_costs_fields_promo_codes"; break;
 case "var_assegna_con_regola2":  		$messaggio = "var_assign_with_rule1"; break;
 case "var_considera_motivazioni_regola1":  	$messaggio = "var_motivations_of_rule1_to_consider"; break;
 case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_show_alternative_phrase_for_rule1"; break;
@@ -355,6 +386,7 @@ case "var_stile_riquadro_calendario":  		$messaggio = "var_calendar_box_style";
 case "var_stile_tabella_calendario":  		$messaggio = "var_calendar_table_style"; break;
 case "var_stile_bottoni_calendario":  		$messaggio = "var_calendar_buttons_style"; break;
 case "var_stile_bottone_apertura_calendario":  	$messaggio = "var_open_calendar_button_style"; break;
+case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
 case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calendar_date"; break;
 case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
 case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
@@ -366,6 +398,7 @@ case "var_tema_modello":  			$messaggio = "var_template_theme"; break;
 case "var_colore_tema":  			$messaggio = "var_theme_color"; break;
 case "var_valore_tema":  			$messaggio = "var_theme_value"; break;
 case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_align_availability_with_arrival"; break;
+case "var_mostra_date_passate":  		$messaggio = "var_show_past_dates"; break;
 case "var_fr_Valuta_sing":  			$messaggio = "var_phr_Currency_sing"; break;
 case "var_fr_Valuta_plur":  			$messaggio = "var_phr_Currency_plur"; break;
 case "var_fr_Controlla_la_disponibilita":  	$messaggio = "var_phr_Check_availability"; break;
@@ -422,6 +455,7 @@ case "var_chiedi_numero_appartamenti_per_tipologia":	$messaggio = "var_ask_numbe
 case "var_massimo_numero_appartamenti_per_tipologia":	$messaggio = "var_maximum_number_apartments_for_type"; break;
 case "var_aggiungi_altre_tipologie":  		$messaggio = "var_add_other_types"; break;
 case "var_massimo_numero_altre_tipologie":  	$messaggio = "var_maximum_number_other_types"; break;
+case "var_cerca_appartamenti_vicini":  		$messaggio = "var_search_nearby_apartments"; break;
 case "var_fr_Numero_di":  			$messaggio = "var_phr_Number_of"; break;
 case "var_fr_Il_numero_di":  			$messaggio = "var_phr_The_number_of"; break;
 case "var_fr_richiesto_e_sbagliato":  		$messaggio = "var_phr_inserted_is_wrong"; break;
@@ -489,6 +523,8 @@ case "var_chiedi_telefono":  			$messaggio = "var_ask_telephone"; break;
 case "var_chiedi_telefono2":  			$messaggio = "var_ask_telephone2"; break;
 case "var_chiedi_telefono3":  			$messaggio = "var_ask_telephone3"; break;
 case "var_chiedi_fax":  			$messaggio = "var_ask_fax"; break;
+case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
+case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
 case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
 case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
 case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
@@ -496,6 +532,7 @@ case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_
 case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
 case "var_campi_form_personalizzati":  		$messaggio = "var_custom_form_fields"; break;
 case "var_chiedi_campi_form_personalizzati":  	$messaggio = "var_ask_custom_form_fields"; break;
+case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fields"; break;
 case "var_campi_form_doc_condizioni":  		$messaggio = "var_doc_conditions_form_fields"; break;
 case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_ask_doc_conditions_form_fields"; break;
 case "var_fr_Cognome":  			$messaggio = "var_phr_Surname"; break;
@@ -512,6 +549,8 @@ case "var_fr_Telefono":  			$messaggio = "var_phr_Telephone"; break;
 case "var_fr_Secondo_telefono":  		$messaggio = "var_phr_Second_telephone"; break;
 case "var_fr_Terzo_telefono":  			$messaggio = "var_phr_Third_telephone"; break;
 case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
+case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
+case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
 case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
 case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
 case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
@@ -528,6 +567,8 @@ case "var_fre_Telefono":  			$messaggio = "var_phre_Telephone"; break;
 case "var_fre_Secondo_telefono":  		$messaggio = "var_phre_Second_telephone"; break;
 case "var_fre_Terzo_telefono":  		$messaggio = "var_phre_Third_telephone"; break;
 case "var_fre_Fax":  				$messaggio = "var_phre_Fax"; break;
+case "var_fre_Codice_fiscale":  		$messaggio = "var_phre_Fiscal_code"; break;
+case "var_fre_Partita_iva":  			$messaggio = "var_phre_VAT_number"; break;
 case "var_fre_Orario_stimato_di_arrivo":  	$messaggio = "var_phre_Estimated_arrival_time"; break;
 case "var_fre_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phre_Deposit_payment_method"; break;
 case "var_fr_campi_necessari":  		$messaggio = "var_phr_required_fields"; break;
@@ -548,9 +589,12 @@ case "var_fr_Data_di_partenza":  		$messaggio = "var_phr_Departure_date"; break;
 case "var_fr_Tipologia":  			$messaggio = "var_phr_Type"; break;
 case "var_fr_Accetto":  			$messaggio = "var_phr_I_accept"; break;
 case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
+case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; break;
+case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
+case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
+case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
-case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
 } # fine switch ($messaggio)
 } # fine else if (substr($messaggio,0,4) != "var_")
 
