@@ -304,6 +304,15 @@ case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo per
 case "tutte le tariffe":  			$messaggio = "all rates"; break;
 case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
 case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
+case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
+case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
+case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
+case "modifica":  				$messaggio = "modify"; break;
+case "In modo predefinito importa":  		$messaggio = "By default import"; break;
+case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
+case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
+case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
+case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
