@@ -249,6 +249,9 @@ case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio =
 case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
 case "Promemoria":  				$messaggio = "Reminder"; break;
 case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "The requested <b>rate</b> is <span class=\"colred\">closed</span> in this period"; break;
+case "cambia il commento":  			$messaggio = "change comment"; break;
+case "Il commento":  				$messaggio = "Comment"; break;
+case "verrà cambiato":  			$messaggio = "will be changed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
