@@ -381,12 +381,32 @@ case "L'accettazione di questa clausola conferma che gli sviluppatori di questo
 case "Accetto":  				$messaggio = "I Accept"; break;
 case "Declino":  				$messaggio = "I Decline"; break;
 case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
-case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
 case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
 case "giornaliero":  				$messaggio = "daily"; break;
 case "mensile":  				$messaggio = "montly"; break;
 case "tabella":  				$messaggio = "table"; break;
+case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
 case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
+case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
+case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
+case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
+case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
+case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
+case "alfabetico":  				$messaggio = "alphabetically"; break;
+case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
+case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
+case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
+case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
+case "Attenzione":  				$messaggio = "Warning"; break;
+case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
+case "La tariffa":  				$messaggio = "Rate"; break;
+case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
+case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
+case "diversa dalle ultime":  			$messaggio = "different from last"; break;
+case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Conditions"; break;
+case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
+case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
+case "password errata":  			$messaggio = "wrong password"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
