@@ -47,7 +47,6 @@ case "Permetti l'inserimento di <i>nuove prenotazioni</i> con le seguenti possib
 case "Possibilità di confermare la prenotazione":	$messaggio = "M&ouml;jlighet att bekr&auml;fta bokningen"; break;
 case "Possibilità di inserire uno sconto":  	$messaggio = "M&ouml;jlighet att infoga rabatt"; break;
 case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "M&ouml;jlighet att infoga extrakostnader"; break;
-case "Possibilità di inserire un commento":  	$messaggio = "M&ouml;jlighet att infoga en kommentar"; break;
 case "Possibilità di inserire il numero di persone":	$messaggio = "M&ouml;jlighet att infoga antalet personer"; break;
 case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "M&ouml;jlighet att infoga bokningar &auml;ven i redan p&aring;b&ouml;rjade perioder"; break;
 case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Bokningar som kan <i>&auml;ndras</i>"; break;
@@ -141,8 +140,6 @@ case "non potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni
 case "potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna infoga en <b>rabatt</b> n&auml;r nya bokningar infogas under"; break;
 case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer inte kunna infoga <b>extrakostnader</b> n&auml;r nya bokningar infogas under"; break;
 case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna infoga <b>extrakostnader</b> n&auml;r nya bokningar infogas under"; break;
-case "non potrà inserire dei <b>commenti</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer inte kunna infoga <b>kommentarer</b> n&auml;r nya bokningar infogas under"; break;
-case "potrà inserire dei <b>commenti</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna infoga <b>kommentarer</b> n&auml;r nya bokningar infogas under"; break;
 case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer inte kunna infoga <b>antal personer</b> n&auml;r nya bokningar infogas under"; break;
 case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna infoga <b>antal personer</b> n&auml;r nya bokningar infogas under"; break;
 case "non potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "kommer inte kunna infoga nya bokningar under <b>redan p&aring;b&ouml;rjade perioder</b> under"; break;
@@ -289,9 +286,21 @@ case "non potrà <b>modificare le quantità dei beni</b>":	$messaggio = "kommer
 case "potrà <b>modificare le quantità dei beni</b>":	$messaggio = "kommer kunna <b>&auml;ndra f&ouml;rem&aring;lskvantitet</b>"; break;
 case "nel":  					$messaggio = "in"; break;
 case "Possibilità di inserire la caparra e le commissioni":	$messaggio = "Possibility to insert deposit and commissions"; break;
+case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
+case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
+case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
+case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
 case "Possibilità di modificare la caparra e le commissioni":  	$messaggio = "Possibility to modify deposit and commissions"; break;
 case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
 case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
+case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
+case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
+case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
+case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
+case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
+case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
+case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
+case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
 case "non potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
 case "potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
 case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "will be able to <b>delete</b> only not begun reservations in"; break;
@@ -332,6 +341,17 @@ case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed
 case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Possibility to delete and overwrite saved documents"; break;
 case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will be able to <b>delete and overwrite documents</b> saved in"; break;
 case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will not be able to <b>delete and overwrite documents</b> saved in"; break;
+case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
+case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
+case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
+case "Modifica dei documenti come API":  	$messaggio = "Modify documents as API"; break;
+case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able to modify <b>documents as API</b>"; break;
+case "Attenzione":  				$messaggio = "Warning"; break;
+case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
+case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
+case "Gestione della password per le carte di credito":	$messaggio = "Management of credit cards password"; break;
+case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "will be able to manage the <b>credit cards password</b>"; break;
+case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "will not be able to manage the <b>credit cards password</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
