@@ -271,6 +271,7 @@ case "Arrotondato_a":  				$messaggio = "Rounded_to"; break;
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
 case "porre per le prenotazioni selezionate":  	$messaggio = "selected reservations to"; break;
 case "cambia":  				$messaggio = "change"; break;
+case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
 case "documento di tipo":  			$messaggio = "document type"; break;
 case "visualizza":  				$messaggio = "view"; break;
 case "Modifica come gruppo le prenotazioni selezionate":	$messaggio = "Modify selected reservations as a group"; break;
@@ -353,10 +354,12 @@ case "password errata":  			$messaggio = "wrong password"; break;
 case "Creare":  				$messaggio = "Create"; break;
 case "persona":  				$messaggio = "person"; break;
 case "chiusa":  				$messaggio = "closed"; break;
-case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
 case "presenti in data":  			$messaggio = "present on"; break;
 case "comprese partenze":  			$messaggio = "including departures"; break;
 case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
+case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
+case "senza letti aggiuntivi":  		$messaggio = "without extra beds"; break;
+case "Premere per modificare":  		$messaggio = "Click to modify"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
